@@ -12,9 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import time
 from ducktape.cluster.cluster_spec import ClusterSpec
 from ducktape.tests.test import Test
 from ducktape.mark import ignore, parametrize
+from ducktape.mark.resource import cluster
+
+
+_flake = False
 
 
 class TestThingy(Test):
@@ -27,6 +32,9 @@ class TestThingy(Test):
     def test_pi(self):
         return {"data": 3.14159}
 
+    def test_delayed(self):
+        time.sleep(1)
+
     @ignore
     def test_ignore1(self):
         pass
@@ -38,3 +46,20 @@ class TestThingy(Test):
 
     def test_failure(self):
         raise Exception("This failed")
+
+    def test_flaky(self):
+        global _flake
+        flake, _flake = _flake, not _flake
+        assert flake
+
+
+class ClusterTestThingy(Test):
+    """Fake ducktape test class"""
+
+    @cluster(num_nodes=10)
+    def test_bad_num_nodes(self):
+        pass
+
+    @cluster(num_nodes=0)
+    def test_good_num_nodes(self):
+        pass
